diff src/backtrace.h @ 771:943eaba38521

[xemacs-hg @ 2002-03-13 08:51:24 by ben] The big ben-mule-21-5 check-in! Various files were added and deleted. See CHANGES-ben-mule. There are still some test suite failures. No crashes, though. Many of the failures have to do with problems in the test suite itself rather than in the actual code. I'll be addressing these in the next day or so -- none of the test suite failures are at all critical. Meanwhile I'll be trying to address the biggest issues -- i.e. build or run failures, which will almost certainly happen on various platforms. All comments should be sent to ben@xemacs.org -- use a Cc: if necessary when sending to mailing lists. There will be pre- and post- tags, something like pre-ben-mule-21-5-merge-in, and post-ben-mule-21-5-merge-in.
author ben
date Wed, 13 Mar 2002 08:54:06 +0000
parents b39c14581166
children a5954632b187
line wrap: on
line diff
--- a/src/backtrace.h	Fri Mar 08 13:33:14 2002 +0000
+++ b/src/backtrace.h	Wed Mar 13 08:54:06 2002 +0000
@@ -148,7 +148,7 @@
 extern struct catchtag *catchlist;
 extern struct backtrace *backtrace_list;
 
 /* Most callers should simply use specbind() and unbind_to(), but if
    speed is REALLY IMPORTANT, you can use the faster macros below */
 void specbind_magic (Lisp_Object, Lisp_Object);
 void grow_specpdl (EMACS_INT reserved);
@@ -224,11 +224,12 @@
     grow_specpdl (SR_size);				\
 } while (0)
 
-/* Inline version of unbind_to().
-   Use this instead of unbind_to() if speed is sufficiently important
-   to save the overhead of even a single function call.
+/* Inline version of unbind_to_1().
+   [[Use this instead of unbind_to_1() if speed is sufficiently important
+   to save the overhead of even a single function call.]]
+   This is bogus pseudo-optimization. --ben
 
-   Most of the time, unbind_to() is called only on ordinary
+   Most of the time, unbind_to_1() is called only on ordinary
    variables, so optimize for that.  */
 #define UNBIND_TO_GCPRO(count, value) do {		\
   int UNBIND_TO_count = (count);			\
@@ -253,7 +254,7 @@
     }							\
 } while (0)
 
 /* A slightly faster inline version of unbind_to,
    that doesn't offer GCPROing services. */
 #define UNBIND_TO(count) do {				\
   int UNBIND_TO_count = (count);			\
@@ -284,7 +285,7 @@
 #if 0
 /* Unused.  It's too hard to guarantee that the current bindings
    contain only variables.  */
 /* Another inline version of unbind_to().  VALUE is GC-protected.
    Caller guarantees that:
    - all of the elements on the binding stack are variable bindings.
    Else we crash.  */
@@ -148,7 +148,7 @@
 extern struct backtrace *backtrace_list;
 
-/* Most callers should simply use specbind() and unbind_to(), but if
+/* Most callers should simply use specbind() and unbind_to_1(), but if
    speed is REALLY IMPORTANT, you can use the faster macros below */
 void specbind_magic (Lisp_Object, Lisp_Object);
@@ -253,7 +254,7 @@
 } while (0)
 
-/* A slightly faster inline version of unbind_to,
+/* A slightly faster inline version of unbind_to_1,
    that doesn't offer GCPROing services. */
 #define UNBIND_TO(count) do {				\
@@ -284,7 +285,7 @@
 /* Unused.  It's too hard to guarantee that the current bindings
    contain only variables.  */
-/* Another inline version of unbind_to().  VALUE is GC-protected.
+/* Another inline version of unbind_to_1().  VALUE is GC-protected.
    Caller guarantees that:
    - all of the elements on the binding stack are variable bindings.